@@ -64,7 +64,7 @@ int main(int argc, char *argv[]) {
     if (!stralloc_cats(&outpath,tempdir)) die_nomem();
     if (!stralloc_append(&outpath, "/")) die_nomem();
     if (!stralloc_cat(&outpath,&outfile)) die_nomem();
-    if(stat(outfile.s,&filestat) == -1 && errno == ENOENT) {
+    if(stat(outpath.s,&filestat) == -1 && errno == ENOENT) {
       if (!stralloc_cats(&dstpath, destdir)) die_nomem();
       if (!stralloc_append(&dstpath, "/")) die_nomem();
       if (!stralloc_cat(&dstpath,&outfile)) die_nomem();
